/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2004 Lincoln Phipps <lincoln.phipps@openmutual.net>
 * Copyright (C) 2002 CodeFactory AB
 * Copyright (C) 2002 Richard Hult <richard@imendio.com>
 * Copyright (C) 2002 Mikael Hallendal <micke@imendio.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <config.h>
#include <glade/glade.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <libplanner/mrp-types.h>
#include <libgnome/gnome-i18n.h>
#include "planner-marshal.h"
#include "planner-task-link-dialog.h"
#include "planner-task-tree.h"

static void
task_link_dialog_free (gpointer user_data)
{
	PlannerLinkDialogData *data = user_data;

	g_object_unref (data->project);

	g_free (data);
}

/* This is here as this source program was cribbed from other dialog code 
*  and used as a template for this dialog.
*/

static void
task_link_dialog_response_cb (GtkWidget *button,
			       gint       response,
			       GtkWidget *dialog)
{
	switch (response) {
		default:
		break;
	}
}

static void
task_link_dialog_setup_option_menu (GtkWidget     *option_menu,
				   GCallback      func,
				   gpointer       user_data,
				   gconstpointer  str1, ...)
{
	GtkWidget    *menu;
	GtkWidget    *menu_item;
	gint          i;
	va_list       args;
	gconstpointer str;
	gint          type;

       	menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (option_menu));
	if (menu) {
		gtk_widget_destroy (menu);
	}
	
	menu = gtk_menu_new ();

	va_start (args, str1);
	for (str = str1, i = 0; str != NULL; str = va_arg (args, gpointer), i++) {
		menu_item = gtk_menu_item_new_with_label (str);
		gtk_widget_show (menu_item);
		gtk_menu_append (GTK_MENU (menu), menu_item);

		type = va_arg (args, gint);
		
		g_object_set_data (G_OBJECT (menu_item),
				   "data",
				   GINT_TO_POINTER (type));
		if (func) {
			g_signal_connect (menu_item,
					  "activate",
					  func,
					  user_data);
		}
	}
	va_end (args);

	gtk_widget_show (menu);
	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), (guint) MRP_RELATION_FS );
}

static void
task_link_dialog_activate_cb (GtkWidget *widget, GtkDialog *dialog)
{
	gtk_dialog_response (dialog, GTK_RESPONSE_OK);
}



GtkWidget *
planner_task_link_dialog_new (MrpProject *project, gint count)
{
	GtkWidget		*dialog;
	PlannerLinkDialogData	*data;
	GladeXML		*gui;

	g_return_val_if_fail (MRP_IS_PROJECT (project), NULL);
	
	data = g_new0 (PlannerLinkDialogData, 1);

	data->project = g_object_ref (project);
	
	gui = glade_xml_new (GLADEDIR "/task-link-dialog.glade",
			     NULL , NULL);
	
	dialog = glade_xml_get_widget (gui, "task_link_dialog"); 
	g_signal_connect (dialog,
			  "response",
			  G_CALLBACK (task_link_dialog_response_cb),
			  dialog);
	
	data->link_relations = glade_xml_get_widget (gui, "link_relations");

	task_link_dialog_setup_option_menu (data->link_relations,
					   NULL,
					   NULL,
					   _("None"), MRP_RELATION_NONE,
					   _("Finish to Start"), MRP_RELATION_FS,
					   _("Finish to Finish"), MRP_RELATION_FF,
					   _("Start to Start"), MRP_RELATION_SS,
					   _("Start to Finish"), MRP_RELATION_SF,
					   NULL);
					   
	
	g_signal_connect (data->link_relations,
			  "activate",
			  G_CALLBACK (task_link_dialog_activate_cb),
			  dialog);
	
	data->lag_text = glade_xml_get_widget (gui, "lag_text");
	g_signal_connect (data->lag_text,
			  "activate",
			  G_CALLBACK (task_link_dialog_activate_cb),
			  dialog);

	data->label_mode = glade_xml_get_widget (gui, "label_mode");

	data->radiobutton_mode_c = glade_xml_get_widget (gui, "radiobutton_mode_c");
	g_signal_connect (data->radiobutton_mode_c,
			  "activate",
			  G_CALLBACK (task_link_dialog_activate_cb),
			  dialog);

	data->radiobutton_mode_fo = glade_xml_get_widget (gui, "radiobutton_mode_fo");
	g_signal_connect (data->radiobutton_mode_fo,
			  "activate",
			  G_CALLBACK (task_link_dialog_activate_cb),
			  dialog);

	data->radiobutton_mode_fi = glade_xml_get_widget (gui, "radiobutton_mode_fi");
	g_signal_connect (data->radiobutton_mode_fi,
			  "activate",
			  G_CALLBACK (task_link_dialog_activate_cb),
			  dialog);

	data->radiobutton_direction_d = glade_xml_get_widget (gui, "radiobutton_direction_d");
	g_signal_connect (data->radiobutton_direction_d,
			  "activate",
			  G_CALLBACK (task_link_dialog_activate_cb),
			  dialog);
	
	data->radiobutton_direction_u = glade_xml_get_widget (gui, "radiobutton_direction_u");
	g_signal_connect (data->radiobutton_direction_u,
			  "activate",
			  G_CALLBACK (task_link_dialog_activate_cb),
			  dialog);

	g_object_set_data_full (G_OBJECT (dialog),
				"data",
				data,
				task_link_dialog_free);

	/* now hide a few things on 2 tasks */

	if (count == 2) {
		gtk_widget_hide(data->label_mode);
		gtk_widget_hide(data->radiobutton_mode_c);
		gtk_widget_hide(data->radiobutton_mode_fo);
		gtk_widget_hide(data->radiobutton_mode_fi);
	}
        return dialog;
}
